Python scdoc to roff and reStructuredText converter
===================================================

Python bindings for mancia, a scdoc to roff and reStructuredText converter.

Install via::

    pip install mancia

See `<https://mancia.readthedocs.io/python-and-sphinx.html>`_ for the
documentation.

